% Auto-generated chapter 42 for tirmidhi
% Hadiths in this chapter: 47

\hadithdefcmd{tirmidhi}{2688}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ وَالَّذِي نَفْسِي بِيَدِهِ لاَ تَدْخُلُوا الْجَنَّةَ حَتَّى تُؤْمِنُوا وَلاَ تُؤْمِنُوا حَتَّى تَحَابُّوا أَلاَ أَدُلُّكُمْ عَلَى أَمْرٍ إِذَا أَنْتُمْ فَعَلْتُمُوهُ تَحَابَبْتُمْ أَفْشُوا السَّلاَمَ بَيْنَكُمْ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ سَلاَمٍ وَشُرَيْحِ بْنِ هَانِئٍ عَنْ أَبِيهِ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو وَالْبَرَاءِ وَأَنَسٍ وَابْنِ عُمَرَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2688}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Narrated Abu Hurairah:that the Messenger of Allah (ﷺ) said: "By the One in Whose Hand is my soul! You will not enter Paradise until you believe, and you will not believe until you love one another. Shall I inform you about a matter which if you do it, then you will love one another? Spread the Salam among each other}}
\hadithdefcmd{tirmidhi}{2689}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ، وَالْحُسَيْنُ بْنُ مُحَمَّدٍ الْحَرِيرِيُّ، بَلْخِيٌّ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، عَنْ جَعْفَرِ بْنِ سُلَيْمَانَ الضُّبَعِيِّ، عَنْ عَوْفٍ، عَنْ أَبِي رَجَاءٍ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، أَنَّ رَجُلاً، جَاءَ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ السَّلاَمُ عَلَيْكُمْ ‏.‏ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ عَشْرٌ ‏"‏ ‏.‏ ثُمَّ جَاءَ آخَرُ فَقَالَ السَّلاَمُ عَلَيْكُمْ وَرَحْمَةُ اللَّهِ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ عِشْرُونَ ‏"‏ ‏.‏ ثُمَّ جَاءَ آخَرُ فَقَالَ السَّلاَمُ عَلَيْكُمْ وَرَحْمَةُ اللَّهِ وَبَرَكَاتُهُ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ ثَلاَثُونَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَفِي الْبَابِ عَنْ عَلِيٍّ وَأَبِي سَعِيدٍ وَسَهْلِ بْنِ حُنَيْفٍ ‏.‏\hadithno{2689}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Imran bin Husain:"A man came to the Prophet (ﷺ) and said: 'As-Salamu 'Alaykum (Peace be upon you).'" [He said:] "So the Prophet (ﷺ) said: 'Ten.' Then another came and he said: 'As-Salamu 'Alaykum Wa Rahmatullah (Peace be upon you, and the mercy of Allah).' So the Prophet (ﷺ) said: 'Twenty.' Then another came and said: 'As-Salamu 'Alaykum Wa Rahmatullahi Wa Barakatuh (Peace be upon you, and the mercy of Allah, and His Blessings).' So the Prophet (ﷺ) said: 'Thirty}}
\hadithdefcmd{tirmidhi}{2690}{حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، حَدَّثَنَا عَبْدُ الأَعْلَى بْنُ عَبْدِ الأَعْلَى، عَنِ الْجُرَيْرِيِّ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ، قَالَ اسْتَأْذَنَ أَبُو مُوسَى عَلَى عُمَرَ فَقَالَ السَّلاَمُ عَلَيْكُمْ أَأَدْخُلُ قَالَ عُمَرُ وَاحِدَةٌ ‏.‏ ثُمَّ سَكَتَ سَاعَةً ثُمَّ قَالَ السَّلاَمُ عَلَيْكُمْ أَأَدْخُلُ قَالَ عُمَرُ ثِنْتَانِ ‏.‏ ثُمَّ سَكَتَ سَاعَةً فَقَالَ السَّلاَمُ عَلَيْكُمْ أَأَدْخُلُ فَقَالَ عُمَرُ ثَلاَثٌ ‏.‏ ثُمَّ رَجَعَ فَقَالَ عُمَرُ لِلْبَوَّابِ مَا صَنَعَ قَالَ رَجَعَ ‏.‏ قَالَ عَلَىَّ بِهِ ‏.‏ فَلَمَّا جَاءَهُ قَالَ مَا هَذَا الَّذِي صَنَعْتَ قَالَ السُّنَّةَ ‏.‏ قَالَ السُّنَّةَ وَاللَّهِ لَتَأْتِيَنِّي عَلَى هَذَا بِبُرْهَانٍ أَوْ بِبَيِّنَةٍ أَوْ لأَفْعَلَنَّ بِكَ ‏.‏ قَالَ فَأَتَانَا وَنَحْنُ رُفْقَةٌ مِنَ الأَنْصَارِ فَقَالَ يَا مَعْشَرَ الأَنْصَارِ أَلَسْتُمْ أَعْلَمَ النَّاسِ بِحَدِيثِ رَسُولِ اللَّهِ صلى الله عليه وسلم أَلَمْ يَقُلْ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الاِسْتِئْذَانُ ثَلاَثٌ فَإِنْ أُذِنَ لَكَ وَإِلاَّ فَارْجِعْ ‏"‏ ‏.‏ فَجَعَلَ الْقَوْمُ يُمَازِحُونَهُ قَالَ أَبُو سَعِيدٍ ثُمَّ رَفَعْتُ رَأْسِي إِلَيْهِ فَقُلْتُ فَمَا أَصَابَكَ فِي هَذَا مِنَ الْعُقُوبَةِ فَأَنَا شَرِيكُكَ ‏.‏ قَالَ فَأَتَى عُمَرَ فَأَخْبَرَهُ بِذَلِكَ فَقَالَ عُمَرُ مَا كُنْتُ عَلِمْتُ بِهَذَا ‏.‏ وَفِي الْبَابِ عَنْ عَلِيٍّ وَأُمِّ طَارِقٍ مَوْلاَةِ سَعْدٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَالْجُرَيْرِيُّ اسْمُهُ سَعِيدُ بْنُ إِيَاسٍ يُكْنَى أَبَا مَسْعُودٍ وَقَدْ رَوَى هَذَا غَيْرُهُ أَيْضًا عَنْ أَبِي نَضْرَةَ وَأَبُو نَضْرَةَ الْعَبْدِيُّ اسْمُهُ الْمُنْذِرُ بْنُ مَالِكِ بْنِ قُطَعَةَ ‏.‏\hadithno{2690}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Narrated Abu Sa'eed:"Abu Musa sought permission to enter upon 'Umar. He said: 'As-Salamu 'Alaykum (Peace be upon you). May I enter?' 'Umar said: 'Once.' Then he was silent for some time. Then he said: 'As-Salamu 'Alaykum (Peace be upon you). May I enter?' 'Umar said: Twice.' Then he was silent for some time. Then he said: 'As-salamu 'Alaykum (Peace be upon you). May I enter?' 'Umar said: 'Three times.' Then he (Abu Musa) left. 'Umar said to the gate-keeper: 'What did he do?' He replied: 'He left." He said: 'Bring him to me.' So when he came, 'Umar said to him: 'What is this that you have done?' He said: 'The Sunnah.' He said: 'The Sunnah? By Allah! You had better bring me proof or a witness to clarify this, or I will do this or that to you.'" He said "So he came to us while we were sitting with Ansar. He said: 'O People of the Ansar! Are you not the most knowledgeable people about the Ahadith of the Messenger of Allah (ﷺ)? Did the Messenger of Allah (ﷺ) not say: "Seeking permission is to be done three time. Either you are permitted, or other wise leave?" The people began joking. Abu Sa'eed said: "Then I raised my head toward him and said: "Whatever punishment you are afflicted with because of this, then I shall be your partner in it." So he went to 'Umar to inform him him about it, and 'Umar said: "I did not know about about this}}
\hadithdefcmd{tirmidhi}{2691}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا عُمَرُ بْنُ يُونُسَ، حَدَّثَنَا عِكْرِمَةُ بْنُ عَمَّارٍ، حَدَّثَنِي أَبُو زُمَيْلٍ، حَدَّثَنِي ابْنُ عَبَّاسٍ، حَدَّثَنِي عُمَرُ بْنُ الْخَطَّابِ، قَالَ اسْتَأْذَنْتُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم ثَلاَثًا فَأَذِنَ لِي ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ وَأَبُو زُمَيْلٍ اسْمُهُ سِمَاكٌ الْحَنَفِيُّ ‏.‏ وَإِنَّمَا أَنْكَرَ عُمَرُ عِنْدَنَا عَلَى أَبِي مُوسَى حَيْثُ رَوَى عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ الاِسْتِئْذَانُ ثَلاَثٌ فَإِنْ أُذِنَ لَكَ وَإِلاَّ فَارْجِعْ ‏"‏ ‏.‏ وَقَدْ كَانَ عُمَرُ اسْتَأْذَنَ عَلَى النَّبِيِّ صلى الله عليه وسلم ثَلاَثًا فَأَذِنَ لَهُ وَلَمْ يَكُنْ عَلِمَ هَذَا الَّذِي رَوَاهُ أَبُو مُوسَى عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ فَإِنْ أُذِنَ لَكَ وَإِلاَّ فَارْجِعْ ‏.‏\hadithno{2691}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Narrated Ibn 'Abbas:that Uman bin Al-Khattab said: "I sought permission (to enter) from the Messenger of Allah (ﷺ) three times, then he permitted me}}
\hadithdefcmd{tirmidhi}{2692}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ دَخَلَ رَجُلٌ الْمَسْجِدَ وَرَسُولُ اللَّهِ صلى الله عليه وسلم جَالِسٌ فِي نَاحِيَةِ الْمَسْجِدِ فَصَلَّى ثُمَّ جَاءَ فَسَلَّمَ عَلَيْهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَعَلَيْكَ ارْجِعْ فَصَلِّ فَإِنَّكَ لَمْ تُصَلِّ ‏"‏ ‏.‏ فَذَكَرَ الْحَدِيثَ بِطُولِهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَرَوَى يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ هَذَا عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ عَنْ سَعِيدٍ الْمَقْبُرِيِّ فَقَالَ عَنْ أَبِيهِ عَنْ أَبِي هُرَيْرَةَ وَلَمْ يَذْكُرْ فِيهِ فَسَلَّمَ عَلَيْهِ وَقَالَ ‏"‏ وَعَلَيْكَ ‏"‏ ‏.‏ قَالَ وَحَدِيثُ يَحْيَى بْنِ سَعِيدٍ أَصَحُّ ‏.‏\hadithno{2692}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Narrated Abu Hurairah:"A man enter the Masjid and performed Salat while the Messenger of Allah (ﷺ) was sitting at the back of the Masjid. Then he came to greet him, so the Prophet (ﷺ) said: "Wa Alaikum (and upon you); go back and pray for indeed you have not prayed.'" And he mentioned the Hadith in its entirety}}
\hadithdefcmd{tirmidhi}{2693}{حَدَّثَنَا عَلِيُّ بْنُ الْمُنْذِرِ الْكُوفِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ زَكَرِيَّا بْنِ أَبِي زَائِدَةَ، عَنْ عَامِرٍ الشَّعْبِيِّ، حَدَّثَنِي أَبُو سَلَمَةَ، أَنَّ عَائِشَةَ، حَدَّثَتْهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ لَهَا ‏ "‏ إِنَّ جِبْرِيلَ يُقْرِئُكِ السَّلاَمَ ‏"‏ ‏.‏ قَالَتْ وَعَلَيْهِ السَّلاَمُ وَرَحْمَةُ اللَّهِ وَبَرَكَاتُهُ ‏.‏ وَفِي الْبَابِ عَنْ رَجُلٍ مِنْ بَنِي نُمَيْرٍ عَنْ أَبِيهِ عَنْ جَدِّهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَقَدْ رَوَاهُ الزُّهْرِيُّ أَيْضًا عَنْ أَبِي سَلَمَةَ عَنْ عَائِشَةَ ‏.‏\hadithno{2693}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Narrated Abu Salamah:that 'Aishah narrated to him that he Messenger of Allah (ﷺ) said to her: "Indeeed Jibril has sent Salam to you." She said: "And upon him be peace and the mercy of Allah and His Blessings}}
\hadithdefcmd{tirmidhi}{2694}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا قُرَّانُ بْنُ تَمَّامٍ الأَسَدِيُّ، عَنْ أَبِي فَرْوَةَ الرَّهَاوِيِّ، يَزِيدَ بْنِ سِنَانٍ عَنْ سُلَيْمِ بْنِ عَامِرٍ، عَنْ أَبِي أُمَامَةَ، قَالَ قِيلَ يَا رَسُولَ اللَّهِ الرَّجُلاَنِ يَلْتَقِيَانِ أَيُّهُمَا يَبْدَأُ بِالسَّلاَمِ فَقَالَ ‏ "‏ أَوْلاَهُمَا بِاللَّهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ قَالَ مُحَمَّدٌ أَبُو فَرْوَةَ الرَّهَاوِيُّ مُقَارِبُ الْحَدِيثِ إِلاَّ أَنَّ ابْنَهُ مُحَمَّدَ بْنَ يَزِيدَ يَرْوِي عَنْهُ مَنَاكِيرَ ‏.‏\hadithno{2694}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abu Umamah:"They said: 'O Messenger of Allah! When two men meet, which of them initiates the Salam?' He said: 'The nearest of them to Allah}}
\hadithdefcmd{tirmidhi}{2695}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا ابْنُ لَهِيعَةَ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَيْسَ مِنَّا مَنْ تَشَبَّهَ بِغَيْرِنَا لاَ تَشَبَّهُوا بِالْيَهُودِ وَلاَ بِالنَّصَارَى فَإِنَّ تَسْلِيمَ الْيَهُودِ الإِشَارَةُ بِالأَصَابِعِ وَتَسْلِيمَ النَّصَارَى الإِشَارَةُ بِالأَكُفِّ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ إِسْنَادُهُ ضَعِيفٌ ‏.‏ وَرَوَى ابْنُ الْمُبَارَكِ هَذَا الْحَدِيثَ عَنِ ابْنِ لَهِيعَةَ فَلَمْ يَرْفَعْهُ ‏.‏\hadithno{2695}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Amr bin Shu'aib:from his father, from his grandfather, that the Messenger of Allah (ﷺ) said: "He is not one of us who resembles other than us, no who resembles the Jews nor the Christians. For indeed greeting of the Jews is pointing the finger, and the greeting of the Christians is waving with the hand}}
\hadithdefcmd{tirmidhi}{2696}{حَدَّثَنَا أَبُو الْخَطَّابِ، زِيَادُ بْنُ يَحْيَى الْبَصْرِيُّ حَدَّثَنَا أَبُو عَتَّابٍ، سَهْلُ بْنُ حَمَّادٍ حَدَّثَنَا شُعْبَةُ، عَنْ سَيَّارٍ، قَالَ كُنْتُ أَمْشِي مَعَ ثَابِتٍ الْبُنَانِيِّ فَمَرَّ عَلَى صِبْيَانٍ فَسَلَّمَ عَلَيْهِمْ فَقَالَ ثَابِتٌ كُنْتُ مَعَ أَنَسٍ فَمَرَّ عَلَى صِبْيَانٍ فَسَلَّمَ عَلَيْهِمْ وَقَالَ أَنَسٌ كُنْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَمَرَّ عَلَى صِبْيَانٍ فَسَلَّمَ عَلَيْهِمْ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ رَوَاهُ غَيْرُ وَاحِدٍ عَنْ ثَابِتٍ وَرُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ أَنَسٍ ‏.‏ حَدَّثَنَا قُتَيْبَةُ حَدَّثَنَا جَعْفَرُ بْنُ سُلَيْمَانَ عَنْ ثَابِتٍ عَنْ أَنَسٍ عَنْ النَّبِيِّ صَلَّى اللَّهُ عَلَيْهِ وَسَلَّمَ نَحْوَهُ\hadithno{2696}\hadithgrade{Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Sayyar:"I was walking with Thabit Al-Bunani. He passed by some boys, so he said Salam to them. Then Thabit said: 'I was with Anas when he passed by some boys and gave the Salam to them, and Anas said: I was with the Prophet (ﷺ) when he passed by some boys and he gave the Salam to them}}
\hadithdefcmd{tirmidhi}{2697}{حَدَّثَنَا سُوَيْدٌ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، أَخْبَرَنَا عَبْدُ الْحَمِيدِ بْنُ بَهْرَامَ، أَنَّهُ سَمِعَ شَهْرَ بْنَ حَوْشَبٍ، يَقُولُ سَمِعْتُ أَسْمَاءَ بِنْتَ يَزِيدَ، تُحَدِّثُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم مَرَّ فِي الْمَسْجِدِ يَوْمًا وَعُصْبَةٌ مِنَ النِّسَاءِ قُعُودٌ فَأَلْوَى بِيَدِهِ بِالتَّسْلِيمِ وَأَشَارَ عَبْدُ الْحَمِيدِ بِيَدِهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ قَالَ أَحْمَدُ بْنُ حَنْبَلٍ لاَ بَأْسَ بِحَدِيثِ عَبْدِ الْحَمِيدِ بْنِ بَهْرَامَ عَنْ شَهْرِ بْنِ حَوْشَبٍ ‏.‏ وَقَالَ مُحَمَّدُ بْنُ إِسْمَاعِيلَ شَهْرٌ حَسَنُ الْحَدِيثِ وَقَوَّى أَمْرَهُ وَقَالَ إِنَّمَا تَكَلَّمَ فِيهِ ابْنُ عَوْنٍ ثُمَّ رَوَى عَنْ هِلاَلِ بْنِ أَبِي زَيْنَبَ عَنْ شَهْرِ بْنِ حَوْشَبٍ ‏.‏ أَنْبَأَنَا أَبُو دَاوُدَ الْمَصَاحِفِيُّ بَلْخِيٌّ أَخْبَرَنَا النَّضْرُ بْنُ شُمَيْلٍ عَنِ ابْنِ عَوْنٍ قَالَ إِنَّ شَهْرًا نَزَكُوهُ ‏.‏ قَالَ أَبُو دَاوُدَ قَالَ النَّضْرُ تَرَكُوهُ أَىْ طَعَنُوا فِيهِ وَإِنَّمَا طَعَنُوا فِيهِ لأَنَّهُ وَلِيَ أَمْرَ السُّلْطَانِ ‏.‏\hadithno{2697}\hadithgrade{Al-Albani: Daif; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Asma bint Yazid:that the Messenger of Allah (ﷺ) passed through the Masjid one day, and a group of women were sitting, so he motioned his hand with the Salam - 'Abdul-Hamid (one of the narrators) gestured with his hand}}
\hadithdefcmd{tirmidhi}{2698}{حَدَّثَنَا أَبُو حَاتِمٍ الْبَصْرِيُّ الأَنْصَارِيُّ، مُسْلِمُ بْنُ حَاتِمٍ حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الأَنْصَارِيُّ، عَنْ أَبِيهِ، عَنْ عَلِيِّ بْنِ زَيْدٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، قَالَ قَالَ أَنَسُ بْنُ مَالِكٍ قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَا بُنَىَّ إِذَا دَخَلْتَ عَلَى أَهْلِكَ فَسَلِّمْ يَكُونُ بَرَكَةً عَلَيْكَ وَعَلَى أَهْلِ بَيْتِكَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{2698}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated Anas:"The Messenger of Allah (ﷺ) said to me: 'O my little son! When you enter upon your family then give the Salam, it will be a blessing for you and upon the inhabitants of your house}}
\hadithdefcmd{tirmidhi}{2699}{حَدَّثَنَا الْفَضْلُ بْنُ الصَّبَّاحِ، - بَغْدَادِيٌّ - حَدَّثَنَا سَعِيدُ بْنُ زَكَرِيَّا، عَنْ عَنْبَسَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ مُحَمَّدِ بْنِ زَاذَانَ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ السَّلاَمُ قَبْلَ الْكَلاَمِ ‏"‏ ‏.‏ وَبِهَذَا الإِسْنَادِ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ لاَ تَدْعُوا أَحَدًا إِلَى الطَّعَامِ حَتَّى يُسَلِّمَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ مُنْكَرٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَسَمِعْتُ مُحَمَّدًا يَقُولُ عَنْبَسَةُ بْنُ عَبْدِ الرَّحْمَنِ ضَعِيفٌ فِي الْحَدِيثِ ذَاهِبٌ وَمُحَمَّدُ بْنُ زَاذَانَ مُنْكَرُ الْحَدِيثِ ‏.‏\hadithno{2699}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Mawdu; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir bin 'Abdullah:that the Messenger of Allah (ﷺ) said: "The Salam is before talking." With this chain it has been reported that the Prophet (ﷺ) said: "Do not invite anyone to the food until the Salam is given}}
\hadithdefcmd{tirmidhi}{2700}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَبْدَءُوا الْيَهُودَ وَالنَّصَارَى بِالسَّلاَمِ وَإِذَا لَقِيتُمْ أَحَدَهُمْ فِي الطَّرِيقِ فَاضْطَرُّوهُمْ إِلَى أَضْيَقِهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2700}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Abu Hurairah:that the Messenger of Allah (ﷺ) said: "Do not precede the Jews and the Christians with the Salam. And if one of you meets them in the path, then force them to its narrow portion}}
\hadithdefcmd{tirmidhi}{2701}{حَدَّثَنَا سَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ الْمَخْزُومِيُّ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ إِنَّ رَهْطًا مِنَ الْيَهُودِ دَخَلُوا عَلَى النَّبِيِّ صلى الله عليه وسلم فَقَالُوا السَّامُ عَلَيْكَ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ عَلَيْكُمْ ‏"‏ ‏.‏ فَقَالَتْ عَائِشَةُ فَقُلْتُ بَلْ عَلَيْكُمُ السَّامُ وَاللَّعْنَةُ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ يَا عَائِشَةُ إِنَّ اللَّهَ يُحِبُّ الرِّفْقَ فِي الأَمْرِ كُلِّهِ ‏"‏ ‏.‏ قَالَتْ عَائِشَةُ أَلَمْ تَسْمَعْ مَا قَالُوا قَالَ ‏"‏ قَدْ قُلْتُ عَلَيْكُمْ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي بَصْرَةَ الْغِفَارِيِّ وَابْنِ عُمَرَ وَأَنَسٍ وَأَبِي عَبْدِ الرَّحْمَنِ الْجُهَنِيِّ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَائِشَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2701}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated 'Aishah:that a group of Jews entered upon the Prophet (ﷺ) and they said: "As-Samu 'Alaik (death be upon you)." So the Prophet (ﷺ) said: "Wa 'Alaik (And upon you)." So 'Aishah said: "I said: '[Rather] upon you be death and the curse.'" So the Prophet (ﷺ) said: "O 'Aishah! Indeed Allah loves gentleness in every matter." 'Aishah said: "Did you not hear what they said?" He said: "And I replied: 'And upon you}}
\hadithdefcmd{tirmidhi}{2702}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، أَنَّ أُسَامَةَ بْنَ زَيْدٍ، أَخْبَرَهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم مَرَّ بِمَجْلِسٍ وَفِيهِ أَخْلاَطٌ مِنَ الْمُسْلِمِينَ وَالْيَهُودِ فَسَلَّمَ عَلَيْهِمْ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2702}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Usamah bin Zaid:that the Prophet (ﷺ) passed by a gathering in which the Muslims and the Jews were mixed, so he gave the Salam to them}}
\hadithdefcmd{tirmidhi}{2703}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَإِبْرَاهِيمُ بْنُ يَعْقُوبَ، قَالاَ حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، عَنْ حَبِيبِ بْنِ الشَّهِيدِ، عَنِ الْحَسَنِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ يُسَلِّمُ الرَّاكِبُ عَلَى الْمَاشِي وَالْمَاشِي عَلَى الْقَاعِدِ وَالْقَلِيلُ عَلَى الْكَثِيرِ ‏"‏ ‏.‏ وَزَادَ ابْنُ الْمُثَنَّى فِي حَدِيثِهِ ‏"‏ وَيُسَلِّمُ الصَّغِيرُ عَلَى الْكَبِيرِ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ عَبْدِ الرَّحْمَنِ بْنِ شِبْلٍ وَفَضَالَةَ بْنِ عُبَيْدٍ وَجَابِرٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ قَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ أَبِي هُرَيْرَةَ ‏.‏ وَقَالَ أَيُّوبُ السَّخْتِيَانِيُّ وَيُونُسُ بْنُ عُبَيْدٍ وَعَلِيُّ بْنُ زَيْدٍ إِنَّ الْحَسَنَ لَمْ يَسْمَعْ مِنْ أَبِي هُرَيْرَةَ ‏.‏\hadithno{2703}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Al-Hasan:from Abu Hurairah that the Prophet (ﷺ) said: "The rider gives the Salam to the walking person, and the walking person to the sitting person and the few to the many." Ibn Al-Muthanna added in his narration: "And the young one gives the Salam to the elder}}
\hadithdefcmd{tirmidhi}{2704}{حَدَّثَنَا سُوَيْدُ بْنُ نَصْرٍ، أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، أَنْبَأَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ يُسَلِّمُ الصَّغِيرُ عَلَى الْكَبِيرِ وَالْمَارُّ عَلَى الْقَاعِدِ وَالْقَلِيلُ عَلَى الْكَثِيرِ ‏"‏ ‏.‏ قَالَ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2704}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Narrated Hammam bin Munabbih:from Abu Hurairah that the Prophet (ﷺ) said: "The young one gives the Salam to the elder, the one passing the by to the one sitting and the few to the many}}
\hadithdefcmd{tirmidhi}{2705}{حَدَّثَنَا سُوَيْدُ بْنُ نَصْرٍ، أَنْبَأَنَا عَبْدُ اللَّهِ، أَنْبَأَنَا حَيْوَةُ بْنُ شُرَيْحٍ، أَخْبَرَنِي أَبُو هَانِئٍ، اسْمُهُ حُمَيْدُ بْنُ هَانِئٍ الْخَوْلاَنِيُّ عَنْ أَبِي عَلِيٍّ الْجَنْبِيِّ، عَنْ فَضَالَةَ بْنِ عُبَيْدٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ يُسَلِّمُ الْفَارِسُ عَلَى الْمَاشِي وَالْمَاشِي عَلَى الْقَائِمِ وَالْقَلِيلُ عَلَى الْكَثِيرِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَأَبُو عَلِيٍّ الْجَنْبِيُّ اسْمُهُ عَمْرُو بْنُ مَالِكٍ ‏.‏\hadithno{2705}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Fadalah bin 'Ubaid:that the Messenger of Allah (ﷺ) said: "The horseman gives Salam to the walking person, the walking person to the one standing and the few to the many}}
\hadithdefcmd{tirmidhi}{2706}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ عَجْلاَنَ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا انْتَهَى أَحَدُكُمْ إِلَى مَجْلِسٍ فَلْيُسَلِّمْ فَإِنْ بَدَا لَهُ أَنْ يَجْلِسَ فَلْيَجْلِسْ ثُمَّ إِذَا قَامَ فَلْيُسَلِّمْ فَلَيْسَتِ الأُولَى بِأَحَقَّ مِنَ الآخِرَةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ أَيْضًا عَنِ ابْنِ عَجْلاَنَ عَنْ سَعِيدٍ الْمَقْبُرِيِّ عَنْ أَبِيهِ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{2706}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Hurairah:that the Messenger of Allah (ﷺ) said: "When one of you arrives at the gathering, then give the Salam, and if he is given a place to sit, then let him sit. Then when he stands, let him give the Salam, the first is more worthy than the last}}
\hadithdefcmd{tirmidhi}{2707}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا ابْنُ لَهِيعَةَ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي جَعْفَرٍ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ الْحُبُلِيِّ، عَنْ أَبِي ذَرٍّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ كَشَفَ سِتْرًا فَأَدْخَلَ بَصَرَهُ فِي الْبَيْتِ قَبْلَ أَنْ يُؤْذَنَ لَهُ فَرَأَى عَوْرَةَ أَهْلِهِ فَقَدْ أَتَى حَدًّا لاَ يَحِلُّ لَهُ أَنْ يَأْتِيَهُ لَوْ أَنَّهُ حِينَ أَدْخَلَ بَصَرَهُ اسْتَقْبَلَهُ رَجُلٌ فَفَقَأَ عَيْنَيْهِ مَا غَيَّرْتُ عَلَيْهِ وَإِنْ مَرَّ رَجُلٌ عَلَى بَابٍ لاَ سِتْرَ لَهُ غَيْرِ مُغْلَقٍ فَنَظَرَ فَلاَ خَطِيئَةَ عَلَيْهِ إِنَّمَا الْخَطِيئَةُ عَلَى أَهْلِ الْبَيْتِ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَأَبِي أُمَامَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ مِثْلَ هَذَا إِلاَّ مِنْ حَدِيثِ ابْنِ لَهِيعَةَ وَأَبُو عَبْدِ الرَّحْمَنِ الْحُبُلِيُّ اسْمُهُ عَبْدُ اللَّهِ بْنُ يَزِيدَ ‏.‏\hadithno{2707}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Dharr:that the Messenger of Allah (ﷺ) said: "Whoever lifts the curtain so that his sight enters the house before he was given permission, and he seeks the nakedness of its inhabitants, then he has done something punishable which was not lawful for him to do. If it were that when he gazed into it, he was facing a man who lanced his eyes, there would be nothing wrong with him doing so. But if a man passes by a door that has no cover over it, and it is not closed and he looks, then there is no sin on him, the sin is only on the inhabitants of the house}}
\hadithdefcmd{tirmidhi}{2708}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الْوَهَّابِ الثَّقَفِيُّ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ فِي بَيْتِهِ فَاطَّلَعَ عَلَيْهِ رَجُلٌ فَأَهْوَى إِلَيْهِ بِمِشْقَصٍ فَتَأَخَّرَ الرَّجُلُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2708}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Narrated Anas:that the Prophet (ﷺ) was in his house when a man looked in at him, so he lunged towards him with an arrow head, so the man backed up}}
\hadithdefcmd{tirmidhi}{2709}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَهْلِ بْنِ سَعْدٍ السَّاعِدِيِّ، أَنَّ رَجُلاً، اطَّلَعَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم مِنْ جُحْرٍ فِي حُجْرَةِ النَّبِيِّ صلى الله عليه وسلم وَمَعَ النَّبِيِّ صلى الله عليه وسلم مِدْرَاةٌ يَحُكُّ بِهَا رَأْسَهُ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لَوْ عَلِمْتُ أَنَّكَ تَنْظُرُ لَطَعَنْتُ بِهَا فِي عَيْنِكَ إِنَّمَا جُعِلَ الاِسْتِئْذَانُ مِنْ أَجْلِ الْبَصَرِ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2709}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Sahl bin Sa'd As-Sa'idi:that a man peeked in on the Messenger of Allah (ﷺ), in one of the apartments of the Prophet (ﷺ), while the Prophet (ﷺ) had a Midrah (an iron comb) with which he was scratching his head. So the Prophet (ﷺ) said: "If I knew that you were looking then I would have poked your eyes with it. Seeking permission has only been enjoined because of the sight}}
\hadithdefcmd{tirmidhi}{2710}{حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، عَنِ ابْنِ جُرَيْجٍ، أَخْبَرَنِي عَمْرُو بْنُ أَبِي سُفْيَانَ، أَنَّ عَمْرَو بْنَ عَبْدِ اللَّهِ بْنِ صَفْوَانَ، أَخْبَرَهُ أَنَّ كَلَدَةَ بْنَ حَنْبَلٍ أَخْبَرَهُ أَنَّ صَفْوَانَ بْنَ أُمَيَّةَ بَعَثَهُ بِلَبَنٍ وَلِبَإٍ وَضَغَابِيسَ إِلَى النَّبِيِّ صلى الله عليه وسلم وَالنَّبِيُّ صلى الله عليه وسلم بِأَعْلَى الْوَادِي قَالَ فَدَخَلْتُ عَلَيْهِ وَلَمْ أُسَلِّمْ وَلَمْ أَسْتَأْذِنْ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ ارْجِعْ فَقُلِ السَّلاَمُ عَلَيْكُمْ أَأَدْخُلُ ‏"‏ ‏.‏ وَذَلِكَ بَعْدَ مَا أَسْلَمَ صَفْوَانُ ‏.‏ قَالَ عَمْرٌو وَأَخْبَرَنِي بِهَذَا الْحَدِيثِ أُمَيَّةُ بْنُ صَفْوَانَ وَلَمْ يَقُلْ سَمِعْتُهُ مِنْ كَلَدَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ ابْنِ جُرَيْجٍ وَرَوَاهُ أَبُو عَاصِمٍ أَيْضًا عَنِ ابْنِ جُرَيْجٍ مِثْلَ هَذَا ‏.‏ وَضَغَابِيسُ هُوَ حَشِيشٌ يُؤْكَلُ ‏.‏\hadithno{2710}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Amr bin Abi Sufyan:that 'Amr bin 'Abdullah bin Safwan informed him, that Kaladah bin Hanbal had informed him, that Safwan bin Umayyah sent him to bring some milk, colostrum, and Daghabis (a type of herb) to the Prophet (ﷺ) while he was in the upper valley. (He said): "I entered upon him without seeking permission nor giving Salam. The Prophet (ﷺ) said: 'Go back and say: As-Salamu Alaykum, may I enter?'" And that was after Safwan had accepted Islam}}
\hadithdefcmd{tirmidhi}{2711}{حَدَّثَنَا سُوَيْدُ بْنُ نَصْرٍ، أَخْبَرَنَا ابْنُ الْمُبَارَكِ، أَنْبَأَنَا شُعْبَةُ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرٍ، قَالَ اسْتَأْذَنْتُ عَلَى النَّبِيِّ صلى الله عليه وسلم فِي دَيْنٍ كَانَ عَلَى أَبِي فَقَالَ ‏"‏ مَنْ هَذَا ‏"‏ ‏.‏ فَقُلْتُ أَنَا ‏.‏ فَقَالَ ‏"‏ أَنَا أَنَا ‏"‏ ‏.‏ كَأَنَّهُ كَرِهَ ذَلِكَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2711}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Jabir:"I sought permission to enter upon the Prophet (ﷺ) regarding a debt my father owed, so he said: 'Who is this?' I said: 'Me.' He said: 'Me, me.'As if he disliked that}}
\hadithdefcmd{tirmidhi}{2712}{أَخْبَرَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الأَسْوَدِ بْنِ قَيْسٍ، عَنْ نُبَيْحٍ الْعَنَزِيِّ، عَنْ جَابِرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَاهُمْ أَنْ يَطْرُقُوا النِّسَاءَ لَيْلاً ‏.‏ وَفِي الْبَابِ عَنْ أَنَسٍ وَابْنِ عُمَرَ وَابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ جَابِرٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ - وَقَدْ رُوِيَ عَنِ ابْنِ عَبَّاسٍ أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَاهُمْ أَنْ يَطْرُقُوا النِّسَاءَ لَيْلاً قَالَ فَطَرَقَ رَجُلاَنِ بَعْدَ نَهْىِ النَّبِيِّ صلى الله عليه وسلم فَوَجَدَ كُلُّ وَاحِدٍ مِنْهُمَا مَعَ امْرَأَتِهِ رَجُلاً ‏.‏\hadithno{2712}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Jabir:that the Prophet (ﷺ) prohibited them from returning to the women from a journey during the night}}
\hadithdefcmd{tirmidhi}{2713}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا شَبَابَةُ، عَنْ حَمْزَةَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا كَتَبَ أَحَدُكُمْ كِتَابًا فَلْيُتَرِّبْهُ فَإِنَّهُ أَنْجَحُ لِلْحَاجَةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ مُنْكَرٌ لاَ نَعْرِفُهُ عَنْ أَبِي الزُّبَيْرِ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ قَالَ وَحَمْزَةُ هُوَ عِنْدِي ابْنُ عَمْرٍو النَّصِيبِيُّ هُوَ ضَعِيفٌ فِي الْحَدِيثِ ‏.‏\hadithno{2713}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir:that the Messenger of Allah (ﷺ) said: "When one of you writes something, then let him Yutarrib (smeared with dust to dry the ink) it, for that is more conducive to the need}}
\hadithdefcmd{tirmidhi}{2714}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ الْحَارِثِ، عَنْ عَنْبَسَةَ، عَنْ مُحَمَّدِ بْنِ زَاذَانَ، عَنْ أُمِّ سَعْدٍ، عَنْ زَيْدِ بْنِ ثَابِتٍ، قَالَ دَخَلْتُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَبَيْنَ يَدَيْهِ كَاتِبٌ فَسَمِعْتُهُ يَقُولُ ‏ "‏ ضَعِ الْقَلَمَ عَلَى أُذُنِكَ فَإِنَّهُ أَذْكَرُ لِلْمُمْلِي ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ وَهُوَ إِسْنَادٌ ضَعِيفٌ ‏.‏ وَعَنْبَسَةُ بْنُ عَبْدِ الرَّحْمَنِ وَمُحَمَّدُ بْنُ زَاذَانَ يُضَعَّفَانِ فِي الْحَدِيثِ ‏.‏\hadithno{2714}\hadithgrade{Ahmad Muhammad Shakir: Mawdu; Al-Albani: Mawdu; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Zaid bin Thabit:"I entered upon the Messenger of Allah (ﷺ) while there was a scribe in front of him, and I heard him saying: 'Put the pen on your ear, for that is more conducive to the scribe remembering}}
\hadithdefcmd{tirmidhi}{2715}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا عَبْدُ الرَّحْمَنِ بْنُ أَبِي الزِّنَادِ، عَنْ أَبِيهِ، عَنْ خَارِجَةَ بْنِ زَيْدِ بْنِ ثَابِتٍ، عَنْ أَبِيهِ، زَيْدِ بْنِ ثَابِتٍ قَالَ أَمَرَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ أَتَعَلَّمَ لَهُ كَلِمَاتِ كِتَابِ يَهُودَ ‏.‏ قَالَ ‏ "‏ إِنِّي وَاللَّهِ مَا آمَنُ يَهُودَ عَلَى كِتَابٍ ‏"‏ ‏.‏ قَالَ فَمَا مَرَّ بِي نِصْفُ شَهْرٍ حَتَّى تَعَلَّمْتُهُ لَهُ قَالَ فَلَمَّا تَعَلَّمْتُهُ كَانَ إِذَا كَتَبَ إِلَى يَهُودَ كَتَبْتُ إِلَيْهِمْ وَإِذَا كَتَبُوا إِلَيْهِ قَرَأْتُ لَهُ كِتَابَهُمْ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رُوِيَ مِنْ غَيْرِ هَذَا الْوَجْهِ عَنْ زَيْدِ بْنِ ثَابِتٍ رَوَاهُ الأَعْمَشُ عَنْ ثَابِتِ بْنِ عُبَيْدٍ الأَنْصَارِيِّ عَنْ زَيْدِ بْنِ ثَابِتٍ قَالَ أَمَرَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ أَتَعَلَّمَ السُّرْيَانِيَّةَ ‏.‏\hadithno{2715}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Zaid bin Thabit:"The Messenger of Allah (ﷺ) ordered me to learn some statements from writings of the Jews for him, and he said: 'For indeed by Allah! I do no trust the Jews with my letters.'" He said: "Half a month did not pass before I learned it, when he (ﷺ) wanted to write to the Jews I would write it to them, and when they wrote to him I would read their letters to him}}
\hadithdefcmd{tirmidhi}{2716}{حَدَّثَنَا يُوسُفُ بْنُ حَمَّادٍ الْبَصْرِيُّ، حَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَتَبَ قَبْلَ مَوْتِهِ إِلَى كِسْرَى وَإِلَى قَيْصَرَ وَإِلَى النَّجَاشِيِّ وَإِلَى كُلِّ جَبَّارٍ يَدْعُوهُمْ إِلَى اللَّهِ وَلَيْسَ بِالنَّجَاشِيِّ الَّذِي صَلَّى عَلَيْهِ النَّبِيُّ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏\hadithno{2716}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Anas bin Malik:"Before he died, the Messenger of Allah (ﷺ) had written to Kisra, Ceasar, An-Najashi, and to every tyrant calling them to Allah. This An-Najashi is not the one that the Prophet (ﷺ) performed to the funeral Salat for}}
\hadithdefcmd{tirmidhi}{2717}{حَدَّثَنَا سُوَيْدُ بْنُ نَصْرٍ، أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، أَنْبَأَنَا يُونُسُ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّهُ أَخْبَرَهُ أَنَّ أَبَا سُفْيَانَ بْنَ حَرْبٍ أَخْبَرَهُ أَنَّ هِرَقْلَ أَرْسَلَ إِلَيْهِ فِي نَفَرٍ مِنْ قُرَيْشٍ وَكَانُوا تُجَّارًا بِالشَّامِ فَأَتَوْهُ فَذَكَرَ الْحَدِيثَ قَالَ ثُمَّ دَعَا بِكِتَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقُرِئَ فَإِذَا فِيهِ بِسْمِ اللَّهِ الرَّحْمَنِ الرَّحِيمِ مِنْ مُحَمَّدٍ عَبْدِ اللَّهِ وَرَسُولِهِ إِلَى هِرَقْلَ عَظِيمِ الرُّومِ السَّلاَمُ عَلَى مَنِ اتَّبَعَ الْهُدَى أَمَّا بَعْدُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَأَبُو سُفْيَانَ اسْمُهُ صَخْرُ بْنُ حَرْبٍ ‏.‏\hadithno{2717}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Ibn 'Abbas:that Abu Sufyan bin Harb informed him that Hiraql had sent for him while he was with a party of the Quraish, and they were trading in Ash-Sham, so they went to him." And he mentioned the Hadith and said: "Then he called for the letter of the Messenger of Allah (ﷺ) to be read, and it said in it: 'In the Name of Allah, the Merciful, the Beneficent. From Muhammad, Allah's Slave and His Messenger, to Hiraql the leader of Rome. Peace be upon whoever follows the guidance. To proceed:}}
\hadithdefcmd{tirmidhi}{2718}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ لَمَّا أَرَادَ نَبِيُّ اللَّهِ صلى الله عليه وسلم أَنْ يَكْتُبَ إِلَى الْعَجَمِ قِيلَ لَهُ إِنَّ الْعَجَمَ لاَ يَقْبَلُونَ إِلاَّ كِتَابًا عَلَيْهِ خَاتَمٌ فَاصْطَنَعَ خَاتَمًا ‏.‏ قَالَ فَكَأَنِّي أَنْظُرُ إِلَى بَيَاضِهِ فِي كَفِّهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2718}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Narrated Anas bin Malik:"When the Prophet of Allah (ﷺ) wanted to write to the foreigners, it was said to him: 'The foreigners do not accept a letter unless it has a seal.' So he had a ring made." He said: "It is as if I am now looking at its whiteness in his hand}}
\hadithdefcmd{tirmidhi}{2719}{حَدَّثَنَا سُوَيْدٌ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، أَخْبَرَنَا سُلَيْمَانُ بْنُ الْمُغِيرَةِ، حَدَّثَنَا ثَابِتٌ الْبُنَانِيُّ، حَدَّثَنَا ابْنُ أَبِي لَيْلَى، عَنِ الْمِقْدَادِ بْنِ الأَسْوَدِ، قَالَ أَقْبَلْتُ أَنَا وَصَاحِبَانِ، لِي قَدْ ذَهَبَتْ أَسْمَاعُنَا وَأَبْصَارُنَا مِنَ الْجَهْدِ فَجَعَلْنَا نَعْرِضُ أَنْفُسَنَا عَلَى أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم فَلَيْسَ أَحَدٌ يَقْبَلُنَا فَأَتَيْنَا النَّبِيَّ صلى الله عليه وسلم فَأَتَى بِنَا أَهْلَهُ فَإِذَا ثَلاَثَةُ أَعْنُزٍ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ احْتَلِبُوا هَذَا اللَّبَنَ بَيْنَنَا ‏"‏ ‏.‏ فَكُنَّا نَحْتَلِبُهُ فَيَشْرَبُ كُلُّ إِنْسَانٍ نَصِيبَهُ وَنَرْفَعُ لِرَسُولِ اللَّهِ صلى الله عليه وسلم نَصِيبَهُ فَيَجِيءُ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنَ اللَّيْلِ فَيُسَلِّمُ عَلَيْنَا تَسْلِيمًا لاَ يُوقِظُ النَّائِمَ وَيُسْمِعُ الْيَقْظَانَ ثُمَّ يَأْتِي الْمَسْجِدَ فَيُصَلِّي ثُمَّ يَأْتِي شَرَابَهُ فَيَشْرَبُهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2719}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Al-Miqdad bin Al-Aswad:"Two of my companions and I went and presented ourselves to the Companions of the Prophet (ﷺ), for our hearing and sight had gone from suffering (hunger and thirst). But there was no one who would accept us. So we went to the Prophet (ﷺ) and he brought us to his family where there were three goats. The Prophet (ﷺ) said: 'Milk these.' We milked them, and each person drank his share, and we put aside a share for the Messenger of Allah (ﷺ). The Messenger of Allah (ﷺ) came during the night and gave the Salam such that it would not wake the sleeping person, and the one who was awake could hear it. Then he went to the Masjid to per form Salat. Then he went for his drink and drank it}}
\hadithdefcmd{tirmidhi}{2720}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، وَنَصْرُ بْنُ عَلِيٍّ، قَالاَ حَدَّثَنَا أَبُو أَحْمَدَ، عَنْ سُفْيَانَ، عَنِ الضَّحَّاكِ بْنِ عُثْمَانَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَجُلاً، سَلَّمَ عَلَى النَّبِيِّ صلى الله عليه وسلم وَهُوَ يَبُولُ فَلَمْ يَرُدَّ عَلَيْهِ يَعْنِي السَّلاَمَ ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى النَّيْسَابُورِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، عَنْ سُفْيَانَ، عَنِ الضَّحَّاكِ بْنِ عُثْمَانَ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏ وَفِي الْبَابِ عَنْ عَلْقَمَةَ بْنِ الْفَغْوَاءِ، وَجَابِرٍ، وَالْبَرَاءِ، وَالْمُهَاجِرِ بْنِ قُنْفُذٍ، ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2720}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Ibn 'Umar:that a man gave the Salam to the Prophet (ﷺ) while he was urinating, but the Prophet (ﷺ) did not return the Salam to him}}
\hadithdefcmd{tirmidhi}{2721}{حَدَّثَنَا سُوَيْدٌ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا خَالِدٌ الْحَذَّاءُ، عَنْ أَبِي تَمِيمَةَ الْهُجَيْمِيِّ، عَنْ رَجُلٍ، مِنْ قَوْمِهِ قَالَ طَلَبْتُ النَّبِيَّ صلى الله عليه وسلم فَلَمْ أَقْدِرْ عَلَيْهِ فَجَلَسْتُ فَإِذَا نَفَرٌ هُوَ فِيهِمْ وَلاَ أَعْرِفُهُ وَهُوَ يُصْلِحُ بَيْنَهُمْ فَلَمَّا فَرَغَ قَامَ مَعَهُ بَعْضُهُمْ فَقَالُوا يَا رَسُولَ اللَّهِ ‏.‏ فَلَمَّا رَأَيْتُ ذَلِكَ قُلْتُ عَلَيْكَ السَّلاَمُ يَا رَسُولَ اللَّهِ عَلَيْكَ السَّلاَمُ يَا رَسُولَ اللَّهِ عَلَيْكَ السَّلاَمُ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ إِنَّ عَلَيْكَ السَّلاَمُ تَحِيَّةُ الْمَيِّتِ إِنَّ عَلَيْكَ السَّلاَمُ تَحِيَّةُ الْمَيِّتِ ‏"‏ ‏.‏ ثَلاَثًا ثُمَّ أَقْبَلَ عَلَىَّ فَقَالَ ‏"‏ إِذَا لَقِيَ الرَّجُلُ أَخَاهُ الْمُسْلِمَ فَلْيَقُلِ السَّلاَمُ عَلَيْكُمْ وَرَحْمَةُ اللَّهِ ‏"‏ ‏.‏ ثُمَّ رَدَّ عَلَىَّ النَّبِيُّ صلى الله عليه وسلم قَالَ ‏"‏ وَعَلَيْكَ وَرَحْمَةُ اللَّهِ وَعَلَيْكَ وَرَحْمَةُ اللَّهِ وَعَلَيْكَ وَرَحْمَةُ اللَّهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَقَدْ رَوَى هَذَا الْحَدِيثَ أَبُو غِفَارٍ، عَنْ أَبِي تَمِيمَةَ الْهُجَيْمِيِّ، عَنْ أَبِي جُرَىٍّ، جَابِرِ بْنِ سُلَيْمٍ الْهُجَيْمِيِّ قَالَ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَذَكَرَ الْحَدِيثَ ‏.‏ وَأَبُو تَمِيمَةَ اسْمُهُ طَرِيفُ بْنُ مُجَالِدٍ ‏\hadithno{2721}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abu Tamimah Al-Hujaimi:from a man among his people, who said: "I went looking for the Prophet (ﷺ) but I was not able to find him. So I sat down, and then I saw a group of people, and he was among them, but I did not recognize him. He was settling some matter between them so when he was finished, some of them stood up with him and they were saying: 'O Messenger of Allah.' When I saw that, I said: "'Alaikas-Salam (upon you be peace) O Messenger of Allah! 'Alaikas-Salam (upon you be peace) O Messenger of Allah! 'Alaikas-Salam (upon you be peace) O Messenger of Allah!' He replied: 'Indeed "'Alaikas-Salam (upon you be peace)" is the greeting for the dead.' Then he came toward me and said: 'When a man meets his Muslim brother then he should say: "As-Salamu 'Alaikum Wa Rahmatullahi Wa Barakatuh (peace be upon you, and the mercy and blessings of Allah)." Then the Prophet (ﷺ) responded to my greeting, he said: 'And may Allah's mercy be upon you, and may Allah's mercy be upon you, and may Allah's mercy be upon you}}
\hadithdefcmd{tirmidhi}{2722}{حَدَّثَنَا بِذَلِكَ الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ حَدَّثَنَا أَبُو أُسَامَةَ عَنْ أَبِي غِفَارٍ الْمُثَنَّى بْنِ سَعِيدٍ الطَّائِيِّ عَنْ أَبِي تَمِيمَةَ الْهُجَيْمِيِّ عَنْ جَابِرِ بْنِ سُلَيْمٍ قَالَ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَقُلْتُ عَلَيْكَ السَّلاَمُ ‏.‏ فَقَالَ ‏ "‏ لاَ تَقُلْ عَلَيْكَ السَّلاَمُ وَلَكِنْ قُلِ السَّلاَمُ عَلَيْكَ ‏"‏ ‏.‏ وَذَكَرَ قِصَّةً طَوِيلَةً وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2722}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abu Ghifar Al-Muthanna bin Sa'eed At-Ta'i:from Abu Tamimah al-Hujaimi from Jabir bin Sulaim who said: "I went to the Prophet (ﷺ) and I said: ''Alaikas-Salam (upon you be peace)' so he replied: 'Do not say "'Alaikas-Salam" rather say As-Salamu Alaik.'" And he mentioned the story in its entirety}}
\hadithdefcmd{tirmidhi}{2723}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا عَبْدُ الصَّمَدِ بْنُ عَبْدِ الْوَارِثِ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُثَنَّى، حَدَّثَنَا ثُمَامَةُ بْنُ عَبْدِ اللَّهِ بْنِ أَنَسِ بْنِ مَالِكٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا سَلَّمَ سَلَّمَ ثَلاَثًا وَإِذَا تَكَلَّمَ بِكَلِمَةٍ أَعَادَهَا ثَلاَثًا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏\hadithno{2723}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Narrated Anas bin Malik:"When the Messenger of Allah (ﷺ) would give the Salam he would do so three times, and when he would say a statement, he would say it three times}}
\hadithdefcmd{tirmidhi}{2724}{حَدَّثَنَا الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكٌ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَبِي مُرَّةَ، مَوْلَى عَقِيلِ بْنِ أَبِي طَالِبٍ عَنْ أَبِي وَاقِدٍ اللَّيْثِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَيْنَمَا هُوَ جَالِسٌ فِي الْمَسْجِدِ وَالنَّاسُ مَعَهُ إِذْ أَقْبَلَ ثَلاَثَةُ نَفَرٍ فَأَقْبَلَ اثْنَانِ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَذَهَبَ وَاحِدٌ فَلَمَّا وَقَفَا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم سَلَّمَا فَأَمَّا أَحَدُهُمَا فَرَأَى فُرْجَةً فِي الْحَلْقَةِ فَجَلَسَ فِيهَا وَأَمَّا الآخَرُ فَجَلَسَ خَلْفَهُمْ وَأَمَّا الآخَرُ فَأَدْبَرَ ذَاهِبًا فَلَمَّا فَرَغَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَلاَ أُخْبِرُكُمْ عَنِ النَّفَرِ الثَّلاَثَةِ أَمَّا أَحَدُهُمْ فَأَوَى إِلَى اللَّهِ فَآوَاهُ اللَّهُ وَأَمَّا الآخَرُ فَاسْتَحْيَا فَاسْتَحْيَا اللَّهُ مِنْهُ وَأَمَّا الآخَرُ فَأَعْرَضَ فَأَعْرَضَ اللَّهُ عَنْهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَأَبُو وَاقِدٍ اللَّيْثِيُّ اسْمُهُ الْحَارِثُ بْنُ عَوْفٍ وَأَبُو مُرَّةَ مَوْلَى أُمِّ هَانِئٍ بِنْتِ أَبِي طَالِبٍ وَاسْمُهُ يَزِيدُ وَيُقَالُ مَوْلَى عَقِيلِ بْنِ أَبِي طَالِبٍ ‏.‏\hadithno{2724}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Abu Waqid Al-Laithi:"The Messenger of Allah (ﷺ) was sitting in the Masjid and the people were with him when three people came. Two of them came near the Messenger of Allah (ﷺ) and one went away. When the two stopped at the Messenger of Allah (ﷺ) the said the Salam. One of them saw an opening in the circle so he sat there. As for the other one, he sat behind them, and the other one went way in the rear. When the Messenger of Allah (ﷺ) had finished, he said: 'Shall I inform you about the three people? As for one of them, he took himself to Allah so Allah took him. The other, he was shy so Allah (had mercy) on him. As for the other one, he turned away, so Allah turned away from him}}
\hadithdefcmd{tirmidhi}{2725}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا شَرِيكٌ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ كُنَّا إِذَا أَتَيْنَا النَّبِيَّ صلى الله عليه وسلم جَلَسَ أَحَدُنَا حَيْثُ يَنْتَهِي ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏ وَقَدْ رَوَاهُ زُهَيْرُ بْنُ مُعَاوِيَةَ عَنْ سِمَاكٍ أَيْضًا ‏.‏\hadithno{2725}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir bin Samurah:"When we went to the Prophet (ﷺ), each of us would sit wherever he wound up at}}
\hadithdefcmd{tirmidhi}{2726}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ، وَلَمْ يَسْمَعْهُ مِنْهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم مَرَّ بِنَاسٍ مِنَ الأَنْصَارِ وَهُمْ جُلُوسٌ فِي الطَّرِيقِ فَقَالَ ‏ "‏ إِنْ كُنْتُمْ لاَ بُدَّ فَاعِلِينَ فَرُدُّوا السَّلاَمَ وَأَعِينُوا الْمَظْلُومَ وَاهْدُوا السَّبِيلَ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَأَبِي شُرَيْحٍ الْخُزَاعِيِّ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{2726}\hadithgrade{Ahmad Muhammad Shakir: Sahih Matn; Al-Albani: Sahih Matn; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Shu'bah:"From Abu Ishaq, from Al-Bara - and he did not hear it from him - the Messenger of Allah (ﷺ) passed by some people from the Ansar while they were sitting in the road. He said: 'If you people must do this, then return the Salam, assist the wronged, and give directions to the one who is on the route}}
\hadithdefcmd{tirmidhi}{2727}{حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، وَإِسْحَاقُ بْنُ مَنْصُورٍ، قَالاَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنِ الأَجْلَحِ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا مِنْ مُسْلِمَيْنِ يَلْتَقِيَانِ فَيَتَصَافَحَانِ إِلاَّ غُفِرَ لَهُمَا قَبْلَ أَنْ يَفْتَرِقَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ حَدِيثِ أَبِي إِسْحَاقَ عَنِ الْبَرَاءِ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنِ الْبَرَاءِ مِنْ غَيْرِ وَجْهٍ وَالأَجْلَحُ هُوَ ابْنُ عَبْدِ اللَّهِ بْنِ حُجَيَّةَ بْنِ عَدِيٍّ الْكِنْدِيُّ ‏.‏\hadithno{2727}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Al-Bara bin 'Azib:that the Messenger of Allah (ﷺ) said: "No two Muslims meet each other and shake hands, except that Allah forgives them before they part}}
\hadithdefcmd{tirmidhi}{2728}{حَدَّثَنَا سُوَيْدٌ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا حَنْظَلَةُ بْنُ عُبَيْدِ اللَّهِ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَجُلٌ يَا رَسُولَ اللَّهِ الرَّجُلُ مِنَّا يَلْقَى أَخَاهُ أَوْ صَدِيقَهُ أَيَنْحَنِي لَهُ قَالَ ‏"‏ لاَ ‏"‏ ‏.‏ قَالَ أَفَيَلْتَزِمُهُ وَيُقَبِّلُهُ قَالَ ‏"‏ لاَ ‏"‏ ‏.‏ قَالَ أَفَيَأْخُذُ بِيَدِهِ وَيُصَافِحُهُ قَالَ ‏"‏ نَعَمْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{2728}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated Anas bin Malik:that a man said: "O Messenger of Allah! When a man among us meets his brother or his friend should he bow to him?" He said: "No." The man continued: "Should he embrace him and kiss him?" He said: "No." He said: "Should he take his hand and shake it?" He said: "Yes}}
\hadithdefcmd{tirmidhi}{2729}{حَدَّثَنَا سُوَيْدٌ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا هَمَّامٌ، عَنْ قَتَادَةَ، قَالَ قُلْتُ لأَنَسِ بْنِ مَالِكٍ هَلْ كَانَتِ الْمُصَافَحَةُ فِي أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ نَعَمْ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2729}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Narrated Qatadah:that he asked Anas bin Malik: "Did the Companions of the Messenger of Allah (ﷺ) use to shake each other's hand?" He said, "Yes}}
\hadithdefcmd{tirmidhi}{2730}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ الضَّبِّيُّ، حَدَّثَنَا يَحْيَى بْنُ سُلَيْمٍ الطَّائِفِيُّ، عَنْ سُفْيَانَ، عَنْ مَنْصُورٍ، عَنْ خَيْثَمَةَ، عَنْ رَجُلٍ، عَنِ ابْنِ مَسْعُودٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مِنْ تَمَامِ التَّحِيَّةِ الأَخْذُ بِالْيَدِ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنِ الْبَرَاءِ وَابْنِ عُمَرَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ وَلاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ يَحْيَى بْنِ سُلَيْمٍ عَنْ سُفْيَانَ ‏.‏ قَالَ سَأَلْتُ مُحَمَّدَ بْنَ إِسْمَاعِيلَ عَنْ هَذَا الْحَدِيثِ فَلَمْ يَعُدَّهُ مَحْفُوظًا وَقَالَ إِنَّمَا أَرَادَ عِنْدِي حَدِيثَ سُفْيَانَ عَنْ مَنْصُورٍ عَنْ خَيْثَمَةَ عَمَّنْ سَمِعَ ابْنَ مَسْعُودٍ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ لاَ سَمَرَ إِلاَّ لِمُصَلٍّ أَوْ مُسَافِرٍ ‏"‏ ‏.‏ قَالَ مُحَمَّدٌ وَإِنَّمَا يُرْوَى عَنْ مَنْصُورٍ عَنْ أَبِي إِسْحَاقَ عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ أَوْ غَيْرِهِ قَالَ مِنْ تَمَامِ التَّحِيَّةِ الأَخْذُ بِالْيَدِ ‏.‏\hadithno{2730}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibn Mas'ud:that the Prophet (ﷺ) said: "taking hold of the hand is from the completeness of the greeting}}
\hadithdefcmd{tirmidhi}{2731}{حَدَّثَنَا سُوَيْدُ بْنُ نَصْرٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا يَحْيَى بْنُ أَيُّوبَ، عَنْ عُبَيْدِ اللَّهِ بْنِ زَحْرٍ، عَنْ عَلِيِّ بْنِ يَزِيدَ، عَنِ الْقَاسِمِ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ أَبِي أُمَامَةَ، رضى الله عنه أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ تَمَامُ عِيَادَةِ الْمَرِيضِ أَنْ يَضَعَ أَحَدُكُمْ يَدَهُ عَلَى جَبْهَتِهِ أَوْ قَالَ عَلَى يَدِهِ فَيَسْأَلَهُ كَيْفَ هُوَ وَتَمَامُ تَحِيَّاتِكُمْ بَيْنَكُمُ الْمُصَافَحَةُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا إِسْنَادٌ لَيْسَ بِالْقَوِيِّ ‏.‏ قَالَ مُحَمَّدٌ وَعُبَيْدُ اللَّهِ بْنُ زَحْرٍ ثِقَةٌ وَعَلِيُّ بْنُ يَزِيدَ ضَعِيفٌ وَالْقَاسِمُ بْنُ عَبْدِ الرَّحْمَنِ يُكْنَى أَبَا عَبْدِ الرَّحْمَنِ وَهُوَ مَوْلَى عَبْدِ الرَّحْمَنِ بْنِ خَالِدِ بْنِ يَزِيدَ بْنِ مُعَاوِيَةَ وَهُوَ ثِقَةٌ وَالْقَاسِمُ شَامِيٌّ ‏.‏\hadithno{2731}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Umamah:that the Messenger of Allah (ﷺ) said: "From the complete of visiting the ill is that one of you place his hand on his forehead" - or he said - "on his hand, and ask him how he is. And shaking hands completes your greetings among each other}}
\hadithdefcmd{tirmidhi}{2732}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ يَحْيَى بْنِ مُحَمَّدِ بْنِ عَبَّادٍ الْمَدَنِيُّ، حَدَّثَنِي أَبُو يَحْيَى بْنُ مُحَمَّدٍ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ مُحَمَّدِ بْنِ مُسْلِمٍ الزُّهْرِيِّ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، قَالَتْ قَدِمَ زَيْدُ بْنُ حَارِثَةَ الْمَدِينَةَ وَرَسُولُ اللَّهِ صلى الله عليه وسلم فِي بَيْتِي فَأَتَاهُ فَقَرَعَ الْبَابَ فَقَامَ إِلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم عُرْيَانًا يَجُرُّ ثَوْبَهُ وَاللَّهِ مَا رَأَيْتُهُ عُرْيَانًا قَبْلَهُ وَلاَ بَعْدَهُ فَاعْتَنَقَهُ وَقَبَّلَهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ مِنْ حَدِيثِ الزُّهْرِيِّ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{2732}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Aishah:"Zaid bin Harithah arrived in Al-Madinah while the Messenger of Allah (ﷺ) was in his house. So he went and knocked at the door, so the Messenger of Allah (ﷺ) stood naked (1), dragging his garment - and by Allah! I did not see him naked before nor afterwards - and he hugged him and kissed him." (1) They say that the meaning of naked here is that he was not wearing his Rida or upper wrap and it was that which was dragging, so the area between the navel and knees were covered. See Tuhfat Al-Ahwadhi}}
\hadithdefcmd{tirmidhi}{2733}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، وَأَبُو أُسَامَةَ عَنْ شُعْبَةَ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ عَبْدِ اللَّهِ بْنِ سَلِمَةَ، عَنْ صَفْوَانَ بْنِ عَسَّالٍ، قَالَ قَالَ يَهُودِيٌّ لِصَاحِبِهِ اذْهَبْ بِنَا إِلَى هَذَا النَّبِيِّ ‏.‏ فَقَالَ صَاحِبُهُ لاَ تَقُلْ نَبِيٌّ إِنَّهُ لَوْ سَمِعَكَ كَانَ لَهُ أَرْبَعَةُ أَعْيُنٍ ‏.‏ فَأَتَيَا رَسُولَ اللَّهِ صلى الله عليه وسلم فَسَأَلاَهُ عَنْ تِسْعِ آيَاتٍ بَيِّنَاتٍ ‏.‏ فَقَالَ لَهُمْ ‏"‏ لاَ تُشْرِكُوا بِاللَّهِ شَيْئًا وَلاَ تَسْرِقُوا وَلاَ تَزْنُوا وَلاَ تَقْتُلُوا النَّفْسَ الَّتِي حَرَّمَ اللَّهُ إِلاَّ بِالْحَقِّ وَلاَ تَمْشُوا بِبَرِيءٍ إِلَى ذِي سُلْطَانٍ لِيَقْتُلَهُ وَلاَ تَسْحَرُوا وَلاَ تَأْكُلُوا الرِّبَا وَلاَ تَقْذِفُوا مُحْصَنَةً وَلاَ تُوَلُّوا الْفِرَارَ يَوْمَ الزَّحْفِ وَعَلَيْكُمْ خَاصَّةً الْيَهُودَ أَنْ لاَ تَعْتَدُوا فِي السَّبْتِ ‏"‏ ‏.‏ قَالَ فَقَبَّلُوا يَدَهُ وَرِجْلَهُ فَقَالاَ نَشْهَدُ أَنَّكَ نَبِيٌّ ‏.‏ قَالَ ‏"‏ فَمَا يَمْنَعُكُمْ أَنْ تَتَّبِعُونِي ‏"‏ ‏.‏ قَالُوا إِنَّ دَاوُدَ دَعَا رَبَّهُ أَنْ لاَ يَزَالَ فِي ذُرِّيَّتِهِ نَبِيٌّ وَإِنَّا نَخَافُ إِنْ تَبِعْنَاكَ أَنْ تَقْتُلَنَا الْيَهُودُ ‏.‏ وَفِي الْبَابِ عَنْ يَزِيدَ بْنِ الأَسْوَدِ وَابْنِ عُمَرَ وَكَعْبِ بْنِ مَالِكٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2733}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Safwan bin Assal:"A Jew said to his companion: 'Accompany us to this Prophet.' So his companion said: 'Do not say: "Prophet". For if he hears you (say that) then he will be very happy.' So they went to the Messenger of Allah (ﷺ) to question him about nine clear signs. So he said to them: 'Do not associate anything with Allah, nor steal, nor commit unlawful intercourse, nor take a life which Allah has made prohibited prohibited, except for what is required (in the law), nor hasten to damage the reputation of one of power so that he will be killed, nor practice magic, nor consume Riba, nor falsely accuse the chaste woman, nor turn to flee on the day of the march, and for you Jews particularly, to not violate the Sabbath.'" He said: "So they kissed his hands and his feet, and they said: 'We bear witness that you are a Prophet.' So he (ﷺ) said: 'Then what prevents you from following me?' They said: 'Because Dawud supplicated to his Lord that his offspring never be devoid of Prophets and we feared that if we follow you then the Jews will kill us}}
\hadithdefcmd{tirmidhi}{2734}{حَدَّثَنَا إِسْحَاقُ بْنُ مُوسَى الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكٌ، عَنْ أَبِي النَّضْرِ، أَنَّ أَبَا مُرَّةَ، مَوْلَى أُمِّ هَانِئٍ بِنْتِ أَبِي طَالِبٍ أَخْبَرَهُ أَنَّهُ، سَمِعَ أُمَّ هَانِئٍ، تَقُولُ ذَهَبْتُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم عَامَ الْفَتْحِ فَوَجَدْتُهُ يَغْتَسِلُ وَفَاطِمَةُ تَسْتُرُهُ بِثَوْبٍ قَالَتْ فَسَلَّمْتُ فَقَالَ ‏"‏ مَنْ هَذِهِ ‏"‏ ‏.‏ قُلْتُ أَنَا أُمُّ هَانِئٍ فَقَالَ ‏"‏ مَرْحَبًا بِأُمِّ هَانِئٍ ‏"‏ ‏.‏ قَالَ فَذَكَرَ فِي الْحَدِيثِ قِصَّةً طَوِيلَةً هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2734}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Umm Hani:"I went to the Messenger of Allah (ﷺ) during the Year of the Conquest, and I found him performing Ghusl, while Fatimah was screening him with a garment. She said: "So I gave Salam and he said: 'Who is this?' I said: 'I am Umm Hani.' He said: 'Welcome Umm Hani}}
